#                     dBASE Compiler Sample Make File
#              Copyright (c) 1993, Borland International, Inc.
#
# This example Make file defines instructions to create the
# dBASE IV version 2.0 Samples application elements.
#
# This Make file takes advantage of the implicit rules which are
# defined in the builtins.mak file which accompanies this release.
#
# These examples assume all source and object files are in the same
# directory.
#-------------------------------------------------------------------------

# The following conditional steps define the BDC compiler flag settings
# based on the presence of a -DDEBUG on the make command line.  In
# DEBUG mode, the BDC preprocessor output is saved to a file in the
# current directory (.).

!ifdef DEBUG
CFLAGS = $(CFLAGS) -p.
!endif

# Define the following macro to specify to BDL that compact .EXE files
# should be built.
DFLAGS = $(DFLAGS) /S

# The following macros define useful sets of dBASE object files which
# can be referenced in various rules.

# In some cases, to produce the corresponding source files
# (.FRG, .LBG, etc.) needed by the compiler to produce these object
# files, you will have to use the dBASE IV Control Center design
# tools to generate the source files from the original design objects.
 
FORMO = ADDBOOK.FMO CONTACTS.FMO OBJECTS.FMO PHONELOG.FMO

REPORTO = \
 ACCT_REC.FRO\
 ALLNAMES.FRO\
 CARDREC.FRO\
 CODES.FRO\
 CUST.FRO\
 EMPLOYEE.FRO\
 GOODS.FRO\
 INVENTRY.FRO\
 ORDERS.FRO\
 REGIONAL.FRO\
 VENDORS.FRO

LABELO = CARDONLY.LBO INVITES.LBO MAILALL.LBO NAMETAGS.LBO

VIEWO = GUESTS.QBO LOCATOR.QBO NAMESQRY.QBO ADDCODES.UPO

BINFILEO = GETDRIVE.BIN STRSUBST.BIN

BUS_OBJ = \
 BUSINESS.DBO\
 ACCT_REC.DBO\
 AREACODE.DBO\
 BACK_RES.DBO\
 CUST.DBO\
 EMPLOYEE.DBO\
 EMP_REPT.DBO\
 GOODS.DBO\
 HELPER.DBO\
 INVOICES.DBO\
 LIBRARY.DBO\
 MENUS.DBO\
 ORDERS.DBO\
 VENDORS.DBO


# Each of the following pseudo-targets can be referenced explicitly on
# the Make command line.  Notice that there is no explicit command after
# the target: dependent specification.  However, Make will determine
# whether any of the dependent object files is older than its matching
# source file and automatically recompile it via the proper implicit rule
# in builtins.mak.

# The implicit rule for making ".BIN" files assumes that Borland's
# TASM assembler and TLINK linker are installed and locatable via
# the DOS PATH environment variable.  Edit builtins.mak to use other
# vendors' assemblers or linkers.

forms: $(FORMO)

reports: $(REPORTO)

labels: $(LABELO)

views: $(VIEWO)
	
binfiles: $(BINFILEO)


# Following are simple rules to create the demonstrations of new,
# improved mouse and event features.  These rules take advantage
# of the implicit rule in builtins.mak.
# A suggested Make command line to build dochisel.exe is:
#
#      MAKE -fsamples.mak dochisel.exe 

dochisel.exe: dochisel.dbo

movewin.exe: movewin.dbo

barcount.exe: barcount.dbo

mrowcol.exe: mrowcol.dbo

onmouse.exe: mrowcol.dbo

# The following rule creates the AREACODE sample application as a
# compact .EXE.

areacode.exe: areacode.dbo library.dbo
  BDL -EAREACODE /S /BAREACODE $**


# Following is a rule which creates the Business sample application
# as a compact .EXE.  This rules takes advantage of the implicit rule
# for compiling .PRG files into .DBO files.  If none of the .DBO
# files is newer than business.exe, the link step will also be skipped.
# This rule uses the "in-line file" feature to produce a list file of
# the .DBO files for BDL to process.

BUSINESS.EXE: $(BUS_OBJ)
  BDL -EBUSINESS.EXE /S /BBUSINESS @&&"
 BUSINESS.DBO
 ACCT_REC.DBO
 AREACODE.DBO
 BACK_RES.DBO
 CUST.DBO
 EMPLOYEE.DBO
 EMP_REPT.DBO
 GOODS.DBO
 HELPER.DBO
 INVOICES.DBO
 LIBRARY.DBO
 MENUS.DBO
 ORDERS.DBO
 VENDORS.DBO
"


# The following pseudo-target will cause ALL of the elements of the
# dBASE IV version 2.0 Samples applications to be created.

samples: business.exe dochisel.exe movewin.exe barcount.exe\
 mrowcol.exe onmouse.exe areacode.exe\
 $(VIEWO) $(FORMO) $(REPORTO) $(LABELO) $(BINFILEO)


# Following is a general purpose rule which will compile and link all
# .PRG files in the current directory.  The make command must include
# a -DSTART=<procname> parameter to name the procedure which should be
# first executed in the linked .EXE.  In this case, the linker is called
# automatically by BDC and directed to created a standalone .EXE.
#
# The dir /B option is only supported in MS-DOS 5.0 or later.
#
# The use of the BDC @<filename> option, rather than expanding the
# list in-line, ensures that the BDC command line will not become
# too long.  A DOS command line is limited to 127 characters.

bigapp:
!ifdef START
 dir *.prg /B > zzzzzbig.src
 bdc @zzzzzbig.src -B$(START) -E$(START) -L
 del zzzzzbig.src
!else
 @echo You MUST define the START macro on the command line!
 @echo Please view the SAMPLES.MAK file for further instructions.
!endif
